==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/InMageRcmPolicyCreationInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.InMageRcmPolicyCreationInputArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * InMageRcm policy creation input.
 * @property appConsistentFrequencyInMinutes The app consistent snapshot frequency (in minutes).
 * @property crashConsistentFrequencyInMinutes The crash consistent snapshot frequency (in minutes).
 * @property enableMultiVmSync A value indicating whether multi-VM sync has to be enabled.
 * @property instanceType The class type.
 * Expected value is 'InMageRcm'.
 * @property recoveryPointHistoryInMinutes The duration in minutes until which the recovery points need to be stored.
 */
public data class InMageRcmPolicyCreationInputArgs(
    public val appConsistentFrequencyInMinutes: Output<Int>? = null,
    public val crashConsistentFrequencyInMinutes: Output<Int>? = null,
    public val enableMultiVmSync: Output<String>? = null,
    public val instanceType: Output<String>,
    public val recoveryPointHistoryInMinutes: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.InMageRcmPolicyCreationInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.InMageRcmPolicyCreationInputArgs =
        com.pulumi.azurenative.recoveryservices.inputs.InMageRcmPolicyCreationInputArgs.builder()
            .appConsistentFrequencyInMinutes(appConsistentFrequencyInMinutes?.applyValue({ args0 -> args0 }))
            .crashConsistentFrequencyInMinutes(
                crashConsistentFrequencyInMinutes?.applyValue({ args0 ->
                    args0
                }),
            )
            .enableMultiVmSync(enableMultiVmSync?.applyValue({ args0 -> args0 }))
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .recoveryPointHistoryInMinutes(
                recoveryPointHistoryInMinutes?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [InMageRcmPolicyCreationInputArgs].
 */
@PulumiTagMarker
public class InMageRcmPolicyCreationInputArgsBuilder internal constructor() {
    private var appConsistentFrequencyInMinutes: Output<Int>? = null

    private var crashConsistentFrequencyInMinutes: Output<Int>? = null

    private var enableMultiVmSync: Output<String>? = null

    private var instanceType: Output<String>? = null

    private var recoveryPointHistoryInMinutes: Output<Int>? = null

    /**
     * @param value The app consistent snapshot frequency (in minutes).
     */
    @JvmName("oykoarvmttekjatm")
    public suspend fun appConsistentFrequencyInMinutes(`value`: Output<Int>) {
        this.appConsistentFrequencyInMinutes = value
    }

    /**
     * @param value The crash consistent snapshot frequency (in minutes).
     */
    @JvmName("xwsdbrevtqwaqtjx")
    public suspend fun crashConsistentFrequencyInMinutes(`value`: Output<Int>) {
        this.crashConsistentFrequencyInMinutes = value
    }

    /**
     * @param value A value indicating whether multi-VM sync has to be enabled.
     */
    @JvmName("vytlpignqnspojop")
    public suspend fun enableMultiVmSync(`value`: Output<String>) {
        this.enableMultiVmSync = value
    }

    /**
     * @param value The class type.
     * Expected value is 'InMageRcm'.
     */
    @JvmName("arfyssomfotvfuiy")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value The duration in minutes until which the recovery points need to be stored.
     */
    @JvmName("tfuhrjaliqaxhbls")
    public suspend fun recoveryPointHistoryInMinutes(`value`: Output<Int>) {
        this.recoveryPointHistoryInMinutes = value
    }

    /**
     * @param value The app consistent snapshot frequency (in minutes).
     */
    @JvmName("wjstkxkwkimfbwik")
    public suspend fun appConsistentFrequencyInMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.appConsistentFrequencyInMinutes = mapped
    }

    /**
     * @param value The crash consistent snapshot frequency (in minutes).
     */
    @JvmName("mrtacfbwywbkyofk")
    public suspend fun crashConsistentFrequencyInMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.crashConsistentFrequencyInMinutes = mapped
    }

    /**
     * @param value A value indicating whether multi-VM sync has to be enabled.
     */
    @JvmName("rdivflfjmxperexk")
    public suspend fun enableMultiVmSync(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableMultiVmSync = mapped
    }

    /**
     * @param value The class type.
     * Expected value is 'InMageRcm'.
     */
    @JvmName("ximxxeeojokxyqhy")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value The duration in minutes until which the recovery points need to be stored.
     */
    @JvmName("pkfmdakpjhpwmmlq")
    public suspend fun recoveryPointHistoryInMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.recoveryPointHistoryInMinutes = mapped
    }

    internal fun build(): InMageRcmPolicyCreationInputArgs = InMageRcmPolicyCreationInputArgs(
        appConsistentFrequencyInMinutes = appConsistentFrequencyInMinutes,
        crashConsistentFrequencyInMinutes = crashConsistentFrequencyInMinutes,
        enableMultiVmSync = enableMultiVmSync,
        instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
        recoveryPointHistoryInMinutes = recoveryPointHistoryInMinutes,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/InMageRcmPolicyCreationInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.InMageRcmPolicyCreationInputArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * InMageRcm policy creation input.
 * @property appConsistentFrequencyInMinutes The app consistent snapshot frequency (in minutes).
 * @property crashConsistentFrequencyInMinutes The crash consistent snapshot frequency (in minutes).
 * @property enableMultiVmSync A value indicating whether multi-VM sync has to be enabled.
 * @property instanceType The class type.
 * Expected value is 'InMageRcm'.
 * @property recoveryPointHistoryInMinutes The duration in minutes until which the recovery points need to be stored.
 */
public data class InMageRcmPolicyCreationInputArgs(
    public val appConsistentFrequencyInMinutes: Output<Int>? = null,
    public val crashConsistentFrequencyInMinutes: Output<Int>? = null,
    public val enableMultiVmSync: Output<String>? = null,
    public val instanceType: Output<String>,
    public val recoveryPointHistoryInMinutes: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.InMageRcmPolicyCreationInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.InMageRcmPolicyCreationInputArgs =
        com.pulumi.azurenative.recoveryservices.inputs.InMageRcmPolicyCreationInputArgs.builder()
            .appConsistentFrequencyInMinutes(appConsistentFrequencyInMinutes?.applyValue({ args0 -> args0 }))
            .crashConsistentFrequencyInMinutes(
                crashConsistentFrequencyInMinutes?.applyValue({ args0 ->
                    args0
                }),
            )
            .enableMultiVmSync(enableMultiVmSync?.applyValue({ args0 -> args0 }))
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .recoveryPointHistoryInMinutes(
                recoveryPointHistoryInMinutes?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [InMageRcmPolicyCreationInputArgs].
 */
@PulumiTagMarker
public class InMageRcmPolicyCreationInputArgsBuilder internal constructor() {
    private var appConsistentFrequencyInMinutes: Output<Int>? = null

    private var crashConsistentFrequencyInMinutes: Output<Int>? = null

    private var enableMultiVmSync: Output<String>? = null

    private var instanceType: Output<String>? = null

    private var recoveryPointHistoryInMinutes: Output<Int>? = null

    /**
     * @param value The app consistent snapshot frequency (in minutes).
     */
    @JvmName("msmvtfxxgeayserb")
    public suspend fun appConsistentFrequencyInMinutes(`value`: Output<Int>) {
        this.appConsistentFrequencyInMinutes = value
    }

    /**
     * @param value The crash consistent snapshot frequency (in minutes).
     */
    @JvmName("ftrwycrvalorumul")
    public suspend fun crashConsistentFrequencyInMinutes(`value`: Output<Int>) {
        this.crashConsistentFrequencyInMinutes = value
    }

    /**
     * @param value A value indicating whether multi-VM sync has to be enabled.
     */
    @JvmName("ctqdcofqkdcovqby")
    public suspend fun enableMultiVmSync(`value`: Output<String>) {
        this.enableMultiVmSync = value
    }

    /**
     * @param value The class type.
     * Expected value is 'InMageRcm'.
     */
    @JvmName("pawtcissxdokflef")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value The duration in minutes until which the recovery points need to be stored.
     */
    @JvmName("nqmxwfjpxcjsugew")
    public suspend fun recoveryPointHistoryInMinutes(`value`: Output<Int>) {
        this.recoveryPointHistoryInMinutes = value
    }

    /**
     * @param value The app consistent snapshot frequency (in minutes).
     */
    @JvmName("lunpschlcdaoflya")
    public suspend fun appConsistentFrequencyInMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.appConsistentFrequencyInMinutes = mapped
    }

    /**
     * @param value The crash consistent snapshot frequency (in minutes).
     */
    @JvmName("wxwgbfsrdarjcurs")
    public suspend fun crashConsistentFrequencyInMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.crashConsistentFrequencyInMinutes = mapped
    }

    /**
     * @param value A value indicating whether multi-VM sync has to be enabled.
     */
    @JvmName("cghrepieanxakxrm")
    public suspend fun enableMultiVmSync(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableMultiVmSync = mapped
    }

    /**
     * @param value The class type.
     * Expected value is 'InMageRcm'.
     */
    @JvmName("mdsmfvjkbuyjarpe")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value The duration in minutes until which the recovery points need to be stored.
     */
    @JvmName("gilepvekjfpsllxc")
    public suspend fun recoveryPointHistoryInMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.recoveryPointHistoryInMinutes = mapped
    }

    internal fun build(): InMageRcmPolicyCreationInputArgs = InMageRcmPolicyCreationInputArgs(
        appConsistentFrequencyInMinutes = appConsistentFrequencyInMinutes,
        crashConsistentFrequencyInMinutes = crashConsistentFrequencyInMinutes,
        enableMultiVmSync = enableMultiVmSync,
        instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
        recoveryPointHistoryInMinutes = recoveryPointHistoryInMinutes,
    )
}
